unit DxSoftEx;

// This source code was written by David Fentem, KW4M, and is hereby released into the public domain.

interface

uses Windows;

function  LoadDxSoftExDll :  boolean;
procedure ClearCwRxBuffer;
function  GetCwRxChar (var Ch : char) : boolean;

implementation

type
   TDxsoftExchangeInitFunc       = function (canal_number : integer) : integer; stdcall;
   TDxsoftGetSymFromRxBufferFunc = function                          : integer; stdcall;
   TDxsoftPutSymToTxBufferFunc   = function (sym : char)             : integer; stdcall;
   TDxsoftGetSymFromTxBufferFunc = function                          : integer; stdcall;
   TDxsoftPutSymToRxBufferFunc   = function (sym : char)             : integer; stdcall;

var
   dllHandle : cardinal;

   DxsoftExchangeInit       : TDxsoftExchangeInitFunc;
   DxsoftGetSymFromRxBuffer : TDxsoftGetSymFromRxBufferFunc;
   DxsoftPutSymToTxBuffer   : TDxsoftPutSymToTxBufferFunc;
   DxsoftGetSymFromTxBuffer : TDxsoftGetSymFromTxBufferFunc;
   DxsoftPutSymToRxBuffer   : TDxsoftPutSymToRxBufferFunc;

procedure UnloadDxSoftExDll;
begin
   if dllHandle <> 0 then
      FreeLibrary(dllHandle);
end;

function GetCwRxChar (var Ch : char) : boolean;
var
   I : integer;
begin
   if assigned (DxsoftGetSymFromRxBuffer) then
      begin
         I := DxsoftGetSymFromRxBuffer;
         if I = -1 then
            begin
               Ch     := #0;
               Result := false;
            end
         else
            begin
               Ch     := chr(lo(I));
               Result := true;
            end;
      end
   else
      begin
         Ch     := #0;
         Result := false;
      end;
end;

procedure ClearCwRxBuffer;
var
   Ch        : char;
   ChPresent : boolean;
begin
   repeat
      ChPresent := GetCwRxChar (Ch);
   until ChPresent = false;
end;

function LoadDxSoftExDll :  boolean;
var
  InitResult : integer;
  CanalNum   : integer;
begin
   Result := false;

   dllHandle := LoadLibrary('DXSOFTEX.DLL') ;
   if dllHandle <> 0 then
      begin
         @DxsoftExchangeInit       := GetProcAddress(dllHandle, '_DxsoftExchangeInit') ;
         @DxsoftGetSymFromRxBuffer := GetProcAddress(dllHandle, '_DxsoftGetSymFromRxBuffer');
         @DxsoftPutSymToTxBuffer   := GetProcAddress(dllHandle, '_DxsoftPutSymToTxBuffer');
         @DxsoftGetSymFromTxBuffer := GetProcAddress(dllHandle, '_DxsoftGetSymFromTxBuffer');
         @DxsoftPutSymToRxBuffer   := GetProcAddress(dllHandle, '_DxsoftPutSymToRxBuffer');
         if ((not assigned (DxsoftExchangeInit))       or
             (not assigned (DxsoftGetSymFromRxBuffer)) or
             (not assigned (DxsoftPutSymToTxBuffer))   or
             (not assigned (DxsoftGetSymFromTxBuffer)) or
             (not assigned (DxsoftPutSymToRxBuffer))
            ) then
                begin
                   UnloadDxSoftExDll;
                   exit
                end;

         CanalNum := 1;
         InitResult := DxsoftExchangeInit (CanalNum);
         if InitResult = 0 then
            UnloadDxSoftExDll
         else
            begin
               ClearCwRxBuffer;
               Result := true;
            end;
      end;
end;

initialization
finalization
   UnloadDxSoftExDll;
end.
